@@ -51,6 +51,9 @@
 #define KEY_WIDTH    	       "/apps/gnomine/geometry/width"
 #define KEY_HEIGHT   	       "/apps/gnomine/geometry/height"
 
+/* So that it is only one place if we re-order the menus. */
+#define HINT_MENU_LOC 1
+
 static GtkWidget *mf_frame;
 static GtkWidget *mfield;
 static GtkWidget *pref_dialog = NULL;
@@ -120,6 +123,9 @@ show_face (GtkWidget *pm)
 		gtk_widget_hide (pm_current); 
 	}
 
+	gtk_widget_set_sensitive(gamemenu[HINT_MENU_LOC].widget, 
+				 (pm == pm_cool) || (pm == pm_smile));
+
 	gtk_widget_show (pm);
 	
 	pm_current = pm;
@@ -265,6 +271,7 @@ focus_out_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 		gtk_widget_hide (mf_frame);
 		gtk_widget_show (ralign);
 		gtk_widget_grab_focus (rbutton);
+		gtk_widget_set_sensitive(gamemenu[HINT_MENU_LOC].widget,FALSE);
 
 		games_clock_stop (GAMES_CLOCK (clk)); 
 	}
@@ -275,6 +282,7 @@ resume_game_cb (GtkButton *widget, gpointer data)
 {
 	gtk_widget_hide (ralign);
 	gtk_widget_show (mf_frame);
+	gtk_widget_set_sensitive(gamemenu[HINT_MENU_LOC].widget,TRUE);
 
 	games_clock_start (GAMES_CLOCK (clk));
 }
@@ -384,7 +392,7 @@ about (GtkWidget *widget, gpointer data)
 	const gchar *documenters[] = {
                 NULL
         };
-	const gchar *translator_credits = _("translator_credits");
+	const gchar *translator_credits = _("translator-credits");
 	
 	if (about) {
                 gtk_window_present (GTK_WINDOW (about));
@@ -414,7 +422,7 @@ about (GtkWidget *widget, gpointer data)
 				 _("A Minesweeper clone."),
 				 (const char **)authors,
 				 (const char **)documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
 	
 	if (pixbuf != NULL)
