@@ -1041,7 +1041,7 @@ bg_colour_callback (GtkWidget *widget, gpointer data)
 
 	gtk_color_button_get_color (GTK_COLOR_BUTTON (widget), &colour);
 
-	tmp = g_strdup_printf ("#%02x%02x%02x", colour.red,
+	tmp = g_strdup_printf ("#%04x%04x%04x", colour.red,
 			       colour.green, colour.blue);
 
 	gconf_client_set_string (conf_client,
@@ -1075,7 +1075,6 @@ mapset_changed_cb (GConfClient *client,
 		GTK_BUTTONS_OK,
 		_("This new mapset will take effect when you start "
 		  "a new game, or when Mahjongg is restarted."));
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
@@ -1327,7 +1326,6 @@ no_match (void)
 				GTK_MESSAGE_INFO,
 				GTK_BUTTONS_OK,
 				_("These tiles don't match."));
-		gtk_dialog_set_has_separator (GTK_DIALOG (mb), FALSE);
 		gtk_dialog_run (GTK_DIALOG (mb));
 		gtk_widget_destroy (mb);
         } else
@@ -1373,7 +1371,6 @@ check_free (void)
 						NULL);
 			gtk_dialog_set_default_response (GTK_DIALOG (mb),
 							 GTK_RESPONSE_ACCEPT);
-			gtk_dialog_set_has_separator (GTK_DIALOG (mb), FALSE);
 			if (gtk_dialog_run (GTK_DIALOG (mb)) == GTK_RESPONSE_REJECT)
 				shuffle_tiles_callback (NULL, NULL);
 			gtk_widget_destroy (mb);
@@ -1636,7 +1633,7 @@ about_callback (GtkWidget *widget, gpointer data)
                 NULL
         };
         /* Translator credits */
-        gchar *translator_credits = _("translator_credits");
+        gchar *translator_credits = _("translator-credits");
 
 	{
 		char *filename = NULL;
@@ -1663,7 +1660,7 @@ about_callback (GtkWidget *widget, gpointer data)
 				   "Mahjongg."),
 				 (const gchar **)authors,
 				 (const gchar **)documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 				pixbuf);
 
 	g_signal_connect (G_OBJECT (about), "destroy",
@@ -2046,6 +2043,11 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
 
         if (paused || game_over == GAME_DEAD || game_over == GAME_WON) return;
 
+	/* Make sure no tiles are selected. */
+	if (selected_tile < MAX_TILES) {
+		unselect_tile(selected_tile);
+	}
+
 	ok = shuffle ();
    
 	if (!ok) {
@@ -2057,7 +2059,6 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
 					     GTK_MESSAGE_ERROR,
 					     GTK_BUTTONS_OK,
 					     (_("Sorry, I was unable to find a playable configuration.")));
-		gtk_dialog_set_has_separator (GTK_DIALOG (mb), FALSE);
 		gtk_dialog_run (GTK_DIALOG (mb));
 		gtk_widget_destroy (mb);
 
